@@ -46,6 +46,7 @@ global kb_cve_qid_map_shelve
 global kb_csv_file
 global kb_json_file
 global kb_log_file
+global kb_log_table_name
 global kb_lock_file
 global kb_log_rotate_file
 global kb_table_name
@@ -642,6 +643,7 @@ def setup_kb_vars():
     global kb_csv_file
     global kb_json_file
     global kb_log_file
+    global kb_log_table_name
     global kb_lock_file
     global kb_log_rotate_file
     global kb_table_name
@@ -660,6 +662,7 @@ def setup_kb_vars():
     kb_csv_file = Path(kb_data_dir, "kb.csv")
     kb_json_file = Path(kb_data_dir, "kb.json")
     kb_log_file = Path(qetl_user_log_dir, "kb.log")
+    kb_log_table_name = 'Q_KnowledgeBase_RUN_LOG'
     kb_lock_file = Path(qetl_user_log_dir, ".kb.lock")
     kb_log_rotate_file = Path(qetl_user_log_dir, "kb.1.log")
     kb_table_name = 'Q_KnowledgeBase'
@@ -1249,6 +1252,17 @@ def setup_requests_module_tls_verify_status():
                                        f"reset requests_module_tls_verify_status in etld_config.yaml to True. ")
 
 
+def run_log_csv_columns():
+    csv_columns = ['LOG_DATETIME', 'LOG_LEVEL', 'LOG_WORKFLOW_FUNCTION_NAME', 'LOG_WORKFLOW_DATETIME', 'LOG_USERNAME',
+                   'LOG_FUNCTION_NAME', 'LOG_MESSAGE']
+
+
+def run_log_csv_column_types():
+    csv_columns = {
+    }
+    return csv_columns
+
+
 def kb_csv_columns():
     csv_columns = ['QID', 'TITLE', 'VULN_TYPE', 'SEVERITY_LEVEL', 'CATEGORY', 'LAST_SERVICE_MODIFICATION_DATETIME',
                    'PUBLISHED_DATETIME', 'PATCHABLE', 'DIAGNOSIS', 'CONSEQUENCE', 'SOLUTION', 'PCI_FLAG',
