@@ -9,9 +9,9 @@ import re
 import os
 import stat
 from urllib.parse import urlencode, quote_plus
-from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
-from qualys_etl.etld_lib import etld_lib_config as etld_lib_config
-from qualys_etl.etld_lib import etld_lib_datetime as etld_lib_datetime
+from qualys_etl.etld_lib import etld_lib_functions
+from qualys_etl.etld_lib import etld_lib_config
+from qualys_etl.etld_lib import etld_lib_datetime
 import qualys_etl
 
 global cred_dir
@@ -25,18 +25,20 @@ global http_return_code
 global platform_url
 global injected_stdin_cred
 
-#injected_stdin_cred = {'username': 'tamab_dt4', 'password': 'no.can.do.Q1', 'api_fqdn_server': 'qualysapi.qualys.com'}
 
 # https://www.qualys.com/platform-identification/
 platform_url = {
     'qualysapi.qualys.com': 'gateway.qg1.apps.qualys.com',
     'qualysapi.qg2.apps.qualys.com': 'gateway.qg2.apps.qualys.com',
     'qualysapi.qg3.apps.qualys.com': 'gateway.qg3.apps.qualys.com',
+    'qualysapi.qg4.apps.qualys.com': 'gateway.qg4.apps.qualys.com',
     'qualysapi.qualys.eu': 'gateway.qg1.apps.qualys.eu',
     'qualysapi.qg2.apps.qualys.eu': 'gateway.qg2.apps.qualys.eu',
     'qualysapi.qg1.apps.qualys.in': 'gateway.qg1.apps.qualys.in',
     'qualysapi.qg1.apps.qualys.ca': 'gateway.qg1.apps.qualys.ca',
     'qualysapi.qg1.apps.qualys.ae': 'gateway.qg1.apps.qualys.ae',
+    'qualysapi.qg1.apps.qualys.co.uk': 'gateway.qg1.apps.qualys.co.uk',
+    'qualysapi.qg1.apps.qualys.com.au': 'gateway.qg1.apps.qualys.com.au',
 }
 
 
@@ -78,7 +80,6 @@ def get_qualys_headers(request=None):
 
 def update_cred(new_cred):
     cred_example_file_path = Path(etld_lib_functions.qetl_code_dir, "qualys_etl", "etld_templates", ".etld_cred.yaml")
-    destination_file_path = Path(cred_dir, ".etld_cred.yaml")
     # Get Current .etld_cred.yaml file
     with open(cred_file, 'r', encoding='utf-8') as cred_yaml_file:
         current_cred = yaml.safe_load(cred_yaml_file)
@@ -144,7 +145,8 @@ def get_env_cred() -> dict:
         etld_lib_functions.logger.info(f"Not using .etld_cred.yaml. Found env credentials, "
                                        f"username: {username}, api_fqdn_server:  {api_fqdn_server}")
         if gateway_fqdn_server == "":
-            gateway_fqdn_server = f"{platform_url.get(api_fqdn_server)}"
+            if api_fqdn_server in platform_url.keys():
+                gateway_fqdn_server = f"{platform_url.get(api_fqdn_server)}"
 
     return {'api_fqdn_server': api_fqdn_server,
             'gateway_fqdn_server': gateway_fqdn_server,
@@ -160,7 +162,8 @@ def get_filesystem_cred():
             cred = yaml.safe_load(cred_yaml_file)
             api_fqdn_server = cred.get('api_fqdn_server')
             authorization = 'Basic ' + \
-                            base64.b64encode(f"{cred.get('username')}:{cred.get('password')}".encode('utf-8')).decode('utf-8')
+                            base64.b64encode(
+                                f"{cred.get('username')}:{cred.get('password')}".encode('utf-8')).decode('utf-8')
             username, password = base64.b64decode(authorization.replace("Basic ", "")).decode('utf-8').split(":")
             cred_file_mode = stat.filemode(os.stat(cred_file).st_mode)
             etld_lib_functions.logger.info(f"Found Credentials, Ensure perms are correct for your company. "
@@ -181,7 +184,8 @@ def get_filesystem_cred():
 
     except Exception as e:
         etld_lib_functions.logger.error(f"Please add your subscription credentials to the:  {cred_file}")
-        etld_lib_functions.logger.error(f"   ** Warning: Ensure Credential File permissions are correct for your company.")
+        etld_lib_functions.logger.error(
+            f"   ** Warning: Ensure Credential File permissions are correct for your company.")
         etld_lib_functions.logger.error(f"   ** Warning: Credentials File: {cred_file}")
         cred_file_mode = stat.filemode(os.stat(cred_file).st_mode)
         etld_lib_functions.logger.error(f"   ** Permissions are: {cred_file_mode} for {cred_file}")
@@ -189,15 +193,19 @@ def get_filesystem_cred():
         exit(1)
 
 
-def get_cred(cred_dict=dict()):
+def get_cred(cred_dict={}):
+    global cred_file
+    global cred_dir
+
     if not Path.is_file(cred_file):
-        cred_example_file_path = Path(etld_lib_functions.qetl_code_dir, "qualys_etl", "etld_templates", ".etld_cred.yaml")
+        cred_example_file_path = \
+            Path(etld_lib_functions.qetl_code_dir, "qualys_etl", "etld_templates", ".etld_cred.yaml")
         destination_file_path = Path(cred_dir, ".etld_cred.yaml")
         shutil.copy(str(cred_example_file_path), str(destination_file_path), follow_symlinks=True)
         cred_example_file = open(str(cred_example_file_path), "r", encoding='utf-8')
         cred_example = cred_example_file.read()
         cred_example_file.close()
-        local_date = etld_lib_datetime.get_local_date() # Add date updated to file
+        local_date = etld_lib_datetime.get_local_date()  # Add date updated to file
         cred_example = re.sub('\$DATE', local_date, cred_example)
         cred_file_example = open(str(cred_file), 'w', encoding='utf-8')
         cred_file_example.write(cred_example)
@@ -225,7 +233,7 @@ def get_cred(cred_dict=dict()):
 def get_cookie(update_cookie=True):
     one_hour = (60*60)  # (Sec * Min)
     try:
-        if update_cookie:
+        if update_cookie is True:
             qualys_logout()
             qualys_login()
         if Path(cookie_file).is_file():
@@ -254,7 +262,7 @@ def get_cookie(update_cookie=True):
 def get_bearer(update_bearer=True):
     one_hour = (60*60)  # (Sec * Min)
     try:
-        if update_bearer:
+        if update_bearer is True:
             qualys_gateway_login()
         if Path(bearer_file).is_file():
             age_of_file = etld_lib_datetime.get_seconds_since_last_file_modification(Path(bearer_file))
@@ -346,7 +354,7 @@ def qualys_gateway_login():
 
 
 def get_bearer_stored_in_env(update_bearer=True, cred={}):
-    one_hour = (60*60)  # (Sec * Min)
+    one_hour = 360
     try:
         if update_bearer:
             cred = qualys_gateway_login_store_in_env(cred_dict=cred)
@@ -443,8 +451,8 @@ def qualys_login():
                                     verify=etld_lib_config.requests_module_tls_verify_status)
         http_return_code = response.status_code
         if response.status_code == 200:
-            cookie_dict = response.cookies.get_dict()
-            cookie = f"DWRSESSIONID={cookie_dict['DWRSESSIONID']}; QualysSession={cookie_dict['QualysSession']}"
+            # cookie_dict = response.cookies.get_dict()
+            # cookie = f"DWRSESSIONID={cookie_dict['DWRSESSIONID']}; QualysSession={cookie_dict['QualysSession']}"
             with open(cookie_file, 'w', encoding='utf-8') as cookiefile:
                 # cookiefile.write(cookie)
                 cookiefile.write("DUMMY")
@@ -463,7 +471,8 @@ def qualys_login():
         use_cookie = False
     except requests.exceptions.RequestException as e:
         etld_lib_functions.logger.error(f"Fail - Qualys Login Failed with user")
-        etld_lib_functions.logger.error(f"       Verify Qualys username, password and api_fqdn_server in Credentials File")
+        etld_lib_functions.logger.error(
+            f"       Verify Qualys username, password and api_fqdn_server in Credentials File")
         etld_lib_functions.logger.error(f"             Credentials File: {cred_file}")
         etld_lib_functions.logger.error(f"             username:         {cred_dict['username']}")
         etld_lib_functions.logger.error(f"             api_fqdn_server:  {cred_dict['api_fqdn_server']}")
