@@ -18,7 +18,6 @@ def copy_results_to_external_target(source_list=None, target=None):
                 else:
                     etld_lib_functions.logger.warning(f"file doesn't exists:{str(file_path)} "
                                             f"cannot distribute to {str(target)}")
-                    pass
         except Exception as e:
             etld_lib_functions.logger.error(f"Exception: {e}")
             etld_lib_functions.logger.error(f"Error distributing files.  ")
@@ -26,5 +25,6 @@ def copy_results_to_external_target(source_list=None, target=None):
                                             f"directory accessibility issue: {target}")
             exit(1)
     else:
-        etld_lib_functions.logger.error(f"etld_lib_config_settings.yaml [named]_export_dir directory does not exist: {target}")
+        etld_lib_functions.logger.error(f"Program aborting, etld_lib_config_settings.yaml "
+                                        f"[named]_export_dir directory does not exist: {target}")
         exit(1)
