@@ -9,73 +9,73 @@ from qualys_etl.etld_lib import etld_lib_config
 global count_rows_added_to_table
 
 
-def get_q_knowledgebase_min_max_dates(sqlite_file):
-    min_date = None
-    max_date = None
-    try:
-        conn = sqlite3.connect(sqlite_file)
-        cursor = conn.cursor()
-        select_statement = 'select min(LAST_SERVICE_MODIFICATION_DATETIME) MIN_DATE, ' \
-                           'max(LAST_SERVICE_MODIFICATION_DATETIME) MAX_DATE ' \
-                           'from Q_KnowledgeBase;'
-        cursor.execute(select_statement)
-        records = cursor.fetchall()
-        for row in records:
-            min_date = row[0]
-            max_date = row[1]
-        conn.close()
-    except Exception as e:
-        min_date = 'Not Found'
-        max_date = 'Not Found'
-
-    return min_date, max_date
+# def get_q_knowledgebase_min_max_dates(sqlite_file):
+#     min_date = None
+#     max_date = None
+#     try:
+#         conn = sqlite3.connect(sqlite_file)
+#         cursor = conn.cursor()
+#         select_statement = 'select min(LAST_SERVICE_MODIFICATION_DATETIME) MIN_DATE, ' \
+#                            'max(LAST_SERVICE_MODIFICATION_DATETIME) MAX_DATE ' \
+#                            'from Q_KnowledgeBase;'
+#         cursor.execute(select_statement)
+#         records = cursor.fetchall()
+#         for row in records:
+#             min_date = row[0]
+#             max_date = row[1]
+#         conn.close()
+#     except Exception as e:
+#         min_date = 'Not Found'
+#         max_date = 'Not Found'
+#
+#     return min_date, max_date
 
 
-def get_q_table_min_max_dates(sqlite_file, datetime_field_name, table_name):
-    min_date = None
-    max_date = None
-    try:
-        conn = sqlite3.connect(sqlite_file)
-        cursor = conn.cursor()
-        select_statement = f'select min({datetime_field_name}) MIN_DATE, ' \
-                           f'max({datetime_field_name}) MAX_DATE ' \
-                           f'from {table_name};'
-        cursor.execute(select_statement)
-        records = cursor.fetchall()
-        for row in records:
-            min_date = row[0]
-            max_date = row[1]
-        conn.close()
-    except Exception as e:
-        min_date = 'Not Found'
-        max_date = 'Not Found'
-
-    return min_date, max_date
+# def get_q_table_min_max_dates(sqlite_file, datetime_field_name, table_name):
+#     min_date = None
+#     max_date = None
+#     try:
+#         conn = sqlite3.connect(sqlite_file)
+#         cursor = conn.cursor()
+#         select_statement = f'select min({datetime_field_name}) MIN_DATE, ' \
+#                            f'max({datetime_field_name}) MAX_DATE ' \
+#                            f'from {table_name};'
+#         cursor.execute(select_statement)
+#         records = cursor.fetchall()
+#         for row in records:
+#             min_date = row[0]
+#             max_date = row[1]
+#         conn.close()
+#     except Exception as e:
+#         min_date = 'Not Found'
+#         max_date = 'Not Found'
+#
+#     return min_date, max_date
 
 
-def create_table_q_knowledgebase_in_host_list_detection():
-
-    table_name = 'Q_KnowledgeBase_In_Host_List_Detection'
-    kb_table_name = 'Q_KnowledgeBase'
-    table_statement = f'CREATE TABLE {table_name} as ' \
-                      f'select * from {kb_table_name} ' \
-                      f'where QID in (select distinct(QID) from Q_Host_List_Detection);'
-    try:
-
-        conn = sqlite3.connect()
-        conn.execute(f"DROP TABLE IF EXISTS {table_name};")
-        conn.execute(table_statement)
-        conn.execute(f"DROP TABLE IF EXISTS {kb_table_name};")
-        conn.commit()
-        conn.close()
-        conn = sqlite3.connect(sqlite_file)
-        conn.isolation_level = None
-        conn.execute("VACUUM")
-        conn.close()
-    except Exception as e:
-        etld_lib_functions.logger.error(f"Error creating table: {table_name}, please retry after fixing error")
-        etld_lib_functions.logger.error(f"Exception: {e}")
-        exit(1)
+# def create_table_q_knowledgebase_in_host_list_detection():
+#
+#     table_name = 'Q_KnowledgeBase_In_Host_List_Detection'
+#     kb_table_name = 'Q_KnowledgeBase'
+#     table_statement = f'CREATE TABLE {table_name} as ' \
+#                       f'select * from {kb_table_name} ' \
+#                       f'where QID in (select distinct(QID) from Q_Host_List_Detection);'
+#     try:
+#
+#         conn = sqlite3.connect()
+#         conn.execute(f"DROP TABLE IF EXISTS {table_name};")
+#         conn.execute(table_statement)
+#         conn.execute(f"DROP TABLE IF EXISTS {kb_table_name};")
+#         conn.commit()
+#         conn.close()
+#         conn = sqlite3.connect(sqlite_file)
+#         conn.isolation_level = None
+#         conn.execute("VACUUM")
+#         conn.close()
+#     except Exception as e:
+#         etld_lib_functions.logger.error(f"Error creating table: {table_name}, please retry after fixing error")
+#         etld_lib_functions.logger.error(f"Exception: {e}")
+#         exit(1)
 
 
 class SqliteObj:
@@ -257,7 +257,7 @@ class SqliteObj:
         result = True
         try:
             self.cursor.execute(f"INSERT OR REPLACE INTO {table_name} "
-                                f"VALUES({self.get_values_var(row)},datetime('now','utc'))",
+                                f"VALUES({self.get_values_var(row)},datetime('now'))",
                                 row)
         except Exception as e:
             etld_lib_functions.logger.error(
@@ -269,7 +269,7 @@ class SqliteObj:
     def insert_unique_row_ignore_duplicates(self, table_name: str, row: list):
         result = True
         try:
-            self.cursor.execute(f"INSERT INTO {table_name} VALUES({self.get_values_var(row)},datetime('now','utc'))", row)
+            self.cursor.execute(f"INSERT INTO {table_name} VALUES({self.get_values_var(row)},datetime('now'))", row)
         except sqlite3.IntegrityError as err:
             if 'unique constraint failed' in str(err).lower():
                 result = "duplicate"
@@ -294,7 +294,7 @@ class SqliteObj:
 
     def insert_unique_row(self, table_name: str, values_var: list, row: list, conflict: str):
         try:
-            self.cursor.execute(f"INSERT INTO {table_name} VALUES({values_var},datetime('now','utc'))", row)
+            self.cursor.execute(f"INSERT INTO {table_name} VALUES({values_var},datetime('now'))", row)
         except sqlite3.Error as err:
             etld_lib_functions.logger.error(
                 f"Error inserting row into table: {table_name}, please retry after fixing error")
@@ -432,7 +432,9 @@ class SqliteObj:
         return status_name, status_detail_dict, status_count
 
     def bulk_insert_csv_file(self, table_name, csv_file_name, csv_columns, message="",
-                             display_progress_counter_at_this_number=10000):
+                             display_progress_counter_at_this_number=10000,
+                             delimiter=',', header_present=True,
+                             key_column_index="", key_to_look_for_in_data=""):
         csv.field_size_limit(sys.maxsize)
         sqlite_rows_written = \
             etld_lib_functions.DisplayCounterToLog(
@@ -448,13 +450,20 @@ class SqliteObj:
             csv_headers = ""
             csv_row_list = []
             bulk_insert_count = 100000
-            with open(csv_file_name, "r", encoding='utf-8') as csv_file:
-                csv_reader = csv.reader(csv_file, delimiter=',')
+            with open(csv_file_name, "rt", encoding='utf-8') as csv_file:
+                csv_reader = csv.reader(csv_file, delimiter=delimiter)
                 self.count_rows_added_to_table = 0
-                csv_headers = next(csv_reader)  # Skip Header
+                if header_present is True:
+                    csv_headers = next(csv_reader)  # Skip Header
                 for row in csv_reader:
+                    if isinstance(key_column_index, int):
+                        if key_column_index <= len(row):
+                            if key_to_look_for_in_data in row[key_column_index]:
+                                pass  # Insert row with key.  Ex. 'etl_was 20220122180000'
+                            else:
+                                continue
                     self.cursor.execute(
-                        f"INSERT OR REPLACE INTO {table_name} VALUES({values_var},datetime('now','utc'))", row)
+                        f"INSERT OR REPLACE INTO {table_name} VALUES({values_var},datetime('now'))", row)
                     sqlite_rows_written.display_counter_to_log()
                     self.count_rows_added_to_table += 1
                 self.commit_changes()
