@@ -120,7 +120,7 @@ def update_password(cred):
 
 
 def if_prompt_credentials():
-    def stdin_help():
+    def my_help():
         print(f"You selected -p prompt, but the data provided is invalid.")
         print(f"Please check your values and re-enter.")
 
@@ -136,7 +136,7 @@ def if_prompt_credentials():
                 os.environ['q_api_fqdn_server'] = api_fqdn_server
                 break
             else:
-                stdin_help()
+                my_help()
                 continue
 
         if validate_gateway_fqdn_server(gateway_fqdn_server):
@@ -156,8 +156,8 @@ def valid_json(json_data):
     return True
 
 
-def if_stdin_credentials():
-    def stdin_help():
+def if_user_selected_sending_credentials_via_stdin():
+    def my_help():
         print(f"You selected -s stdin, but the data provided is invalid.")
         print('Example of valid json (gateway is optional): ')
         print('{"q_username":"your userid", "q_password":"your password", "q_api_fqdn_server":"api fqdn", '
@@ -174,11 +174,11 @@ def if_stdin_credentials():
                 pass
             else:
                 print("Invalid JSON...")
-                stdin_help()
+                my_help()
                 exit(1)
         else:
             print("No data set through stdin...")
-            stdin_help()
+            my_help()
             exit(1)
 
         cred = json.loads(stdin_data)
@@ -186,7 +186,7 @@ def if_stdin_credentials():
             pass
         else:
             print("Missing q_username, q_password or q_api_fqdn_server keys...")
-            stdin_help()
+            my_help()
             exit(1)
 
         api_fqdn_server = cred['q_api_fqdn_server']
@@ -202,7 +202,7 @@ def if_stdin_credentials():
             os.environ['q_api_fqdn_server'] = api_fqdn_server
         else:
             print("Invalid q_username, q_password or q_api_fqdn_server...")
-            stdin_help()
+            my_help()
             exit(1)
         if validate_gateway_fqdn_server(gateway_fqdn_server):
             os.environ['q_gateway_fqdn_server'] = gateway_fqdn_server
@@ -211,8 +211,8 @@ def if_stdin_credentials():
         return False
 
 
-def if_memory_credentials():
-    def stdin_help():
+def if_user_selected_setting_credentials_in_memory():
+    def my_help():
         print(f"You selected -m memory, but there is an issue with your environment variables.")
         print(f"Please check your exported q_username, q_password and q_api_fqdn_server.")
         print(f"Please rerun when ready.")
@@ -224,7 +224,7 @@ def if_memory_credentials():
             pass
         else:
             print("Missing q_username, q_password or q_api_fqdn_server from environment...")
-            stdin_help()
+            my_help()
             exit(1)
 
         api_fqdn_server = os.environ['q_api_fqdn_server']
@@ -238,7 +238,7 @@ def if_memory_credentials():
             pass
         else:
             print("Invalid q_username, q_password or q_api_fqdn_server in environment.  Please review your exports...")
-            stdin_help()
+            my_help()
             exit(1)
         if validate_gateway_fqdn_server(gateway_fqdn_server):
             os.environ['q_gateway_fqdn_server'] = gateway_fqdn_server
@@ -247,7 +247,7 @@ def if_memory_credentials():
         return False
 
 
-def if_update_credentials(first_time=False):
+def if_user_selected_update_credentials_stored_on_disk(first_time=False):
     if command_line_arguments.credentials is not None or first_time is not False:
         etld_lib_config.main()
         etld_lib_credentials.main()
@@ -275,14 +275,14 @@ def if_update_credentials(first_time=False):
 
 
 def start_etl_knowledgebase():
-    import qualys_etl.etld_knowledgebase.etld_00_spawn_workflow_manager_knowledgebase as etl_kb_spawn_from_qetl_manage_user
+    import qualys_etl.etld_knowledgebase.knowledgebase_01_spawn_workflow_manager as etl_kb_spawn_from_qetl_manage_user
     print(f"Starting etl_knowledgebase.  For progress see your {etld_lib_config.kb_log_file}")
     etl_kb_spawn_from_qetl_manage_user.main()
     print(f"End      etl_knowledgebase.  For progress see your {etld_lib_config.kb_log_file}")
 
 
 def start_etl_host_list():
-    import qualys_etl.etld_host_list.etld_00_spawn_workflow_manager_host_list \
+    import qualys_etl.etld_host_list.host_list_01_spawn_workflow_manager \
         as etl_host_list_spawn_from_qetl_manage_user
     print(f"Starting etl_host_list.  For progress see: {etld_lib_config.host_list_log_file}")
     etl_host_list_spawn_from_qetl_manage_user.main()
@@ -290,7 +290,7 @@ def start_etl_host_list():
 
 
 def start_etl_asset_inventory():
-    import qualys_etl.etld_asset_inventory.etld_00_spawn_workflow_manager_asset_inventory \
+    import qualys_etl.etld_asset_inventory.asset_inventory_01_spawn_workflow_manager \
         as etl_asset_inventory_spawn_from_qetl_manage_user
     print(f"Starting etl_asset_inventory.  For progress see: {etld_lib_config.asset_inventory_log_file}")
     etl_asset_inventory_spawn_from_qetl_manage_user.main()
@@ -298,14 +298,29 @@ def start_etl_asset_inventory():
 
 
 def start_etl_host_list_detection():
-    import qualys_etl.etld_host_list_detection.etld_00_spawn_workflow_manager_host_list_detection \
+    import qualys_etl.etld_host_list_detection.host_list_detection_01_spawn_workflow_manager \
        as etl_host_list_detection_spawn_from_qetl_manage_user
     print(f"Starting etl_host_list_detection.  For progress see: {etld_lib_config.host_list_detection_log_file}")
     etl_host_list_detection_spawn_from_qetl_manage_user.main()
     print(f"End      etl_host_list_detection.  For results see:  {etld_lib_config.host_list_detection_log_file}")
 
 
-def command_line_arguments_datetime():
+def start_etl_was():
+    import qualys_etl.etld_was.was_01_spawn_workflow_manager \
+        as etl_was_spawn_from_qetl_manage_user
+    print(f"Starting etl_was.  For progress see: {etld_lib_config.was_log_file}")
+    etl_was_spawn_from_qetl_manage_user.main()
+    print(f"End      etl_was.  For results see:  {etld_lib_config.was_log_file}")
+
+
+def start_etl_test_system():
+    from qualys_etl.etld_test_system import test_system_01_spawn_workflow_manager
+    print(f"Starting etl_test_system.  For progress see your {etld_lib_config.test_system_log_file}")
+    test_system_01_spawn_workflow_manager.main()
+    print(f"End      etl_test_system.  For progress see your {etld_lib_config.test_system_log_file}")
+
+
+def validate_and_set_command_line_arguments_datetime_in_etld_lib_config():
     if command_line_arguments.datetime is None:
         pass
     else:
@@ -318,8 +333,8 @@ def command_line_arguments_datetime():
             exit(1)
 
 
-def if_execute_etl_module():
-    command_line_arguments_datetime()
+def if_user_selected_execute_an_etl_module():
+    validate_and_set_command_line_arguments_datetime_in_etld_lib_config()
     if command_line_arguments.execute_etl_module == 'etl_knowledgebase':
         start_etl_knowledgebase()
     elif command_line_arguments.execute_etl_module == 'etl_host_list':
@@ -330,17 +345,25 @@ def if_execute_etl_module():
         start_etl_host_list_detection()
     elif command_line_arguments.execute_etl_module == 'etl_asset_inventory':
         start_etl_asset_inventory()
+    elif command_line_arguments.execute_etl_module == 'etl_was':
+        start_etl_was()
+    elif command_line_arguments.execute_etl_module == 'etl_test_system':
+        start_etl_test_system()
     elif command_line_arguments.execute_etl_module is None:
         pass
     else:
         etld_lib_functions.logger.info(f"Invalid Option: {str(command_line_arguments.execute_etl_module)}, "
                                        f"retry when ready.")
         print(f"\nInvalid Option: {str(command_line_arguments.execute_etl_module)}, retry when ready")
-        print(f"Options are: -e etl_knowledgebase or -e etl_host_list or -e etl_host_list_detection")
+        print(f"Options are: -e etl_knowledgebase ")
+        print(f"Options are: -e etl_host_list")
+        print(f"Options are: -e etl_host_list_detection")
+        print(f"Options are: -e etl_asset_inventory")
+        print(f"Options are: -e etl_test_system")
         exit(1)
 
 
-def if_qualys_test_login(first_time=False):
+def if_user_selected_test_qualys_basic_authentication_login(first_time=False):
     if command_line_arguments.test is not None or first_time is not False:
         etld_lib_functions.main(log_level=logging.INFO, my_logger_prog_name='qetl_manage_user')
         etld_lib_config.main()
@@ -359,7 +382,7 @@ def if_qualys_test_login(first_time=False):
         return False
 
 
-def if_qualys_test_gateway_login(first_time=False):
+def if_user_selected_test_qualys_gateway_token_login(first_time=False):
     if command_line_arguments.test is not None or first_time is not False:
         etld_lib_functions.main(log_level=logging.INFO, my_logger_prog_name='qetl_manage_user')
         etld_lib_config.main()
@@ -375,7 +398,7 @@ def if_qualys_test_gateway_login(first_time=False):
         etld_lib_functions.main(log_level=logging.WARN, my_logger_prog_name='qetl_manage_user')
 
 
-def if_print_report():
+def if_user_selected_print_directory_listing_report():
     if command_line_arguments.report is not None:
         print(f"Report on user: {etld_lib_config.qetl_user_home_dir}")
         for path in sorted(etld_lib_config.qetl_user_home_dir.rglob('*')):
@@ -404,6 +427,7 @@ def help_message(notes):
                                    - /opt/qetl/users/q_username
       -e etl module name,     --execute_etl_module module name
                                   Ex.  -e etl_knowledgebase or -e etl_host_list or -e etl_host_list_detection -e etl_asset_inventory
+                                  Ex.  -e etl_test_system ( for small system test of all ETL jobs )
       -d YYMMDDThh:mm:ssZ,    --datetime        YYYY-MM-DDThh:mm:ssZ UTC. Get All Data On or After Date. 
                                                 Ex. 1970-01-01T00:00:00Z acts as flag to obtain all data.
       -c, --credentials       update qualys api user credentials: qualys username, password or api_fqdn_server
@@ -423,10 +447,10 @@ def help_message(notes):
 
 
 def test_command_line_arguments():
-    results = command_line_arguments
+    global command_line_arguments
     # If no options check for -u.  If -u exists, help_message.  If -u does not exist, continue to new user prompts.
     # If -u is not set, help_message
-    if results.qetl_user_home_dir is None:
+    if command_line_arguments.qetl_user_home_dir is None:
         help_message(f"Please enter -u [ your /opt/qetl/users/ user home directory path ]\n\n"
                      f"    Note: /opt/qetl/users/newuser is the root directory for your qetl userhome directory,\n" 
                      f"    Example:\n"
@@ -434,7 +458,7 @@ def test_command_line_arguments():
                      f" ")
         exit(6)  # 6 is for testing the command works. Ex. qetl_manage_user; if [[ "$?" == "6"]]; then : ...
 
-    test_qetl_user_home_dir = Path(results.qetl_user_home_dir).absolute()
+    test_qetl_user_home_dir = Path(command_line_arguments.qetl_user_home_dir).absolute()
     if test_qetl_user_home_dir.parent.parent.is_dir() and \
             os.access(str(test_qetl_user_home_dir.parent.parent), os.W_OK) and \
             test_qetl_user_home_dir.parent.name == 'users' and \
@@ -446,15 +470,13 @@ def test_command_line_arguments():
                      f"   You don't appear to have authorization to write to that directory.\n")
         exit(1)
 
-    ##TODO Add datetime methods to test date entered.
-
     if test_qetl_user_home_dir.is_dir():
-        if results.execute_etl_module is None and \
-                results.credentials is None and \
-                results.test is None and \
-                results.logs is None and \
-                results.report is None:
-            help_message(f"Please select an option for qetl_user: {results.qetl_user_home_dir}")
+        if command_line_arguments.execute_etl_module is None and \
+                command_line_arguments.credentials is None and \
+                command_line_arguments.test is None and \
+                command_line_arguments.logs is None and \
+                command_line_arguments.report is None:
+            help_message(f"Please select an option for qetl_user: {command_line_arguments.qetl_user_home_dir}")
             exit(1)
     else:
         pass
@@ -482,7 +504,7 @@ def get_command_line_arguments(args=None):
     command_line_arguments = parser.parse_args(args)
 
 
-def setup_qetl_user_home_dir_environment():
+def setup_qualys_etl_user_home_environment_in_memory_and_in_etld_lib_config():
     global qetl_user_home
     global command_line_arguments
     # Reset Logging.
@@ -515,15 +537,15 @@ def setup_qetl_user_home_dir_environment():
             etld_lib_config.main()
             time.sleep(1)
             print(f"\nqetl_user_home_dir created: {etld_lib_config.qetl_user_home_dir}")
-            if_update_credentials(first_time=True)
+            if_user_selected_update_credentials_stored_on_disk(first_time=True)
             response = input(f"\nWould you like to test login/logout of Qualys API? ( yes or no ): ")
             if response == 'yes':
                 print("")
-                if_qualys_test_login(first_time=True)
+                if_user_selected_test_qualys_basic_authentication_login(first_time=True)
             # response = input(f"\nWould you like to test login/logout of Qualys Gateway? ( yes or no ): ")
             # if response == 'yes':
             #     print("")
-            #     if_qualys_test_gateway_login(first_time=True)
+            #     if_user_selected_test_qualys_gateway_token_login(first_time=True)
             print(f"\nThank you, exiting.\n")
             exit(0)
         else:
@@ -534,23 +556,23 @@ def setup_qetl_user_home_dir_environment():
 def main():
     get_command_line_arguments(sys.argv[1:])
     test_command_line_arguments()
-    setup_qetl_user_home_dir_environment()
+    setup_qualys_etl_user_home_environment_in_memory_and_in_etld_lib_config()
 
-    if if_stdin_credentials():
+    if if_user_selected_sending_credentials_via_stdin():
         pass
     elif if_prompt_credentials():
         pass
-    elif if_memory_credentials():
+    elif if_user_selected_setting_credentials_in_memory():
         pass
-    elif if_update_credentials():
+    elif if_user_selected_update_credentials_stored_on_disk():
         pass
 
-    if_qualys_test_login()
+    if_user_selected_test_qualys_basic_authentication_login()
 
-    if if_print_report():
+    if if_user_selected_print_directory_listing_report():
         pass
     else:
-        if_execute_etl_module()
+        if_user_selected_execute_an_etl_module()
 
 
 if __name__ == '__main__':
